@@ -176,6 +176,9 @@ KAlgebra::KAlgebra(QWidget *parent)
                         this, SLOT(saveScript()), Qt::CTRL+Qt::Key_G);
     c_menu->addAction(QIcon::fromTheme(QStringLiteral("document-save")), i18nc("@item:inmenu", "&Export Log..."),
                         this, SLOT(saveLog()), QKeySequence::Save);
+    c_menu->addSeparator();
+    c_menu->addAction(i18nc("@item:inmenu", "&Insert ans..."),
+                        this, SLOT(insertAns()), Qt::Key_F3);
     c_menu->addSeparator()->setText(i18n("Execution Mode"));
     QActionGroup *execGroup = new QActionGroup(c_menu);
     QAction* calc = c_menu->addAction(i18nc("@item:inmenu", "Calculate"), this, SLOT(consoleCalculate()));
@@ -527,6 +530,11 @@ void KAlgebra::saveLog()
         c_results->saveLog(path);
 }
 
+void KAlgebra::insertAns()
+{
+    c_exp->insertText("ans");
+}
+
 void KAlgebra::set_res_low()    { b_funcsModel->setResolution(416); }
 void KAlgebra::set_res_std()    { b_funcsModel->setResolution(832); }
 void KAlgebra::set_res_fine()    { b_funcsModel->setResolution(1664);}
